==> foundation-2.7.1.tgz: package/SocialStumbleupon/SocialStumbleupon.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var SocialStumbleupon = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("g", {
    fillRule: "evenodd",
    clipRule: "evenodd"
  }, /*#__PURE__*/React.createElement("path", {
    d: "M80.801 26.084A38.805 38.805 0 0189 50c0 21.536-17.464 39-38.999 39-15.153 0-28.29-8.646-34.746-21.271h16.998c8.1 0 13.758-4.366 13.758-11.345 0-14.791-17.063-8.765-17.063-14.014 0-2.529 2.029-3.449 5.742-3.449h11.83c3.279 0 7.136.588 7.136 4.166v11.787c0 8.535 6.665 12.854 13.573 12.854 7.026 0 13.571-4.319 13.571-12.854v-28.79h.001z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M50.001 11a38.817 38.817 0 0121.937 6.756V55.15c0 2.592-2.12 4.713-4.708 4.713-2.591 0-4.709-2.121-4.709-4.713V43.945c0-8.945-4.527-12.666-10.423-12.666H32.909c-6.947 0-12.71 4.422-12.71 11.434 0 3.588 1.537 8.846 8.806 10.15 5.921 1.066 8.258.756 8.258 3.924 0 3.076-3.446 3.076-7.995 3.076H12.261A38.94 38.94 0 0111 50c0-21.531 17.466-39 39.001-39z"
  })));
});
SocialStumbleupon.displayName = 'SocialStumbleupon';
export var SocialStumbleuponDimensions = {
  height: 100,
  width: 100
};

==> foundation-10.15.1.tgz: package/SocialStumbleupon/SocialStumbleupon.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { StyledIconBase } from '@styled-icons/styled-icon';
export var SocialStumbleupon = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(StyledIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("g", {
    fillRule: "evenodd",
    clipRule: "evenodd"
  }, /*#__PURE__*/React.createElement("path", {
    d: "M80.801 26.084A38.805 38.805 0 0189 50c0 21.536-17.464 39-38.999 39-15.153 0-28.29-8.646-34.746-21.271h16.998c8.1 0 13.758-4.366 13.758-11.345 0-14.791-17.063-8.765-17.063-14.014 0-2.529 2.029-3.449 5.742-3.449h11.83c3.279 0 7.136.588 7.136 4.166v11.787c0 8.535 6.665 12.854 13.573 12.854 7.026 0 13.571-4.319 13.571-12.854v-28.79h.001z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M50.001 11a38.817 38.817 0 0121.937 6.756V55.15c0 2.592-2.12 4.713-4.708 4.713-2.591 0-4.709-2.121-4.709-4.713V43.945c0-8.945-4.527-12.666-10.423-12.666H32.909c-6.947 0-12.71 4.422-12.71 11.434 0 3.588 1.537 8.846 8.806 10.15 5.921 1.066 8.258.756 8.258 3.924 0 3.076-3.446 3.076-7.995 3.076H12.261A38.94 38.94 0 0111 50c0-21.531 17.466-39 39.001-39z"
  })));
});
SocialStumbleupon.displayName = 'SocialStumbleupon';
export var SocialStumbleuponDimensions = {
  height: 100,
  width: 100
};
